diff --git a/config-templates/authsources.php b/config-templates/authsources.php
index dce39c813fc0ccf15802fe721fb666d0241036a7..4da2abc31e5cc11952c254d4bdca0c2aa78ed890 100644
--- a/config-templates/authsources.php
+++ b/config-templates/authsources.php
@@ -160,16 +160,16 @@ $config = [
     */
 
     /*
     // LinkedIn OAuth Authentication API.
     // Register your application to get an API key here:
-    //  https://www.linkedin.com/secure/developer
-    // Attributes definition:
-    //  https://developer.linkedin.com/docs/fields
-    'linkedin' => [
-        'authlinkedin:LinkedIn',
+    //  http://twitter.com/oauth_clients
+    'twitter' => [
+        'authtwitter:Twitter',
         'key' => 'xxxxxxxxxxxxxxxx',
         'secret' => 'xxxxxxxxxxxxxxxx',
-        'attributes' => 'id,first-name,last-name,headline,summary,specialties,picture-url,email-address',
+        // Forces the user to enter their credentials to ensure the correct users account is authorized.
+        // Details: https://dev.twitter.com/docs/api/1/get/oauth/authenticate
+        'force_login' => false,
     ],
     */
@@ -160,16 +160,16 @@ $config = [
 
     /*
-    // LinkedIn OAuth Authentication API.
+    // Twitter OAuth Authentication API.
     // Register your application to get an API key here: